AppEngineHttpTarget

Struct AppEngineHttpTarget 

#[non_exhaustive]
pub struct AppEngineHttpTarget { pub http_method: HttpMethod, pub app_engine_routing: Option<AppEngineRouting>, pub relative_uri: String, pub headers: HashMap<String, String>, pub body: Bytes, /* private fields */ }
App Engine target. The job will be pushed to a job handler by means of an HTTP request via an http_method such as HTTP POST, HTTP GET, etc. The job is acknowledged by means of an HTTP response code in the range [200 - 299]. Error 503 is considered an App Engine system error instead of an application error. Requests returning error 503 will be retried regardless of retry configuration and not counted against retry counts. Any other response code, or a failure to receive a response before the deadline, constitutes a failed attempt.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
http_method: HttpMethod

The HTTP method to use for the request. PATCH and OPTIONS are not permitted.

app_engine_routing: Option<AppEngineRouting>

App Engine Routing setting for the job.

relative_uri: String

The relative URI.

The relative URL must begin with “/” and must be a valid HTTP relative URL. It can contain a path, query string arguments, and # fragments. If the relative URL is empty, then the root path “/” will be used. No spaces are allowed, and the maximum length allowed is 2083 characters.

headers: HashMap<String, String>

HTTP request headers.

This map contains the header field names and values. Headers can be set when the job is created.

Cloud Scheduler sets some headers to default values:

  • User-Agent: By default, this header is "AppEngine-Google; (+<http://code.google.com/appengine>)". This header can be modified, but Cloud Scheduler will append "AppEngine-Google; (+<http://code.google.com/appengine>)" to the modified User-Agent.
  • X-CloudScheduler: This header will be set to true.
  • X-CloudScheduler-JobName: This header will contain the job name.
  • X-CloudScheduler-ScheduleTime: For Cloud Scheduler jobs specified in the unix-cron format, this header will contain the job schedule as an offset of UTC parsed according to RFC3339.

If the job has a body and the following headers are not set by the user, Cloud Scheduler sets default values:

  • Content-Type: This will be set to "application/octet-stream". You can override this default by explicitly setting Content-Type to a particular media type when creating the job. For example, you can set Content-Type to "application/json".

The headers below are output only. They cannot be set or overridden:

  • Content-Length: This is computed by Cloud Scheduler.
  • X-Google-*: For Google internal use only.
  • X-AppEngine-*: For Google internal use only.

In addition, some App Engine headers, which contain job-specific information, are also be sent to the job handler.

body: Bytes

Body.

HTTP request body. A request body is allowed only if the HTTP method is POST or PUT. It will result in invalid argument error to set a body on a job with an incompatible HttpMethod.

Implementations

Source

impl AppEngineHttpTarget

pub fn new() -> Self

pub fn set_http_method<T: Into<HttpMethod>>(self, v: T) -> Self

Sets the value of http_method.

Example
use google_cloud_scheduler_v1::model::HttpMethod;
let x0 = AppEngineHttpTarget::new().set_http_method(HttpMethod::Post);
let x1 = AppEngineHttpTarget::new().set_http_method(HttpMethod::Get);
let x2 = AppEngineHttpTarget::new().set_http_method(HttpMethod::Head);
pub fn set_app_engine_routing<T>(self, v: T) -> Self

Sets the value of app_engine_routing.

Example
use google_cloud_scheduler_v1::model::AppEngineRouting;
let x = AppEngineHttpTarget::new().set_app_engine_routing(AppEngineRouting::default()/* use setters */);
pub fn set_or_clear_app_engine_routing<T>(self, v: Option<T>) -> Self

Sets or clears the value of app_engine_routing.

Example
use google_cloud_scheduler_v1::model::AppEngineRouting;
let x = AppEngineHttpTarget::new().set_or_clear_app_engine_routing(Some(AppEngineRouting::default()/* use setters */));
let x = AppEngineHttpTarget::new().set_or_clear_app_engine_routing(None::<AppEngineRouting>);
pub fn set_relative_uri<T: Into<String>>(self, v: T) -> Self

Sets the value of relative_uri.

Example
let x = AppEngineHttpTarget::new().set_relative_uri("example");
pub fn set_headers<T, K, V>(self, v: T) -> Self
where T: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<String>,

Sets the value of headers.

Example
let x = AppEngineHttpTarget::new().set_headers([
    ("key0", "abc"),
    ("key1", "xyz"),
]);
pub fn set_body<T: Into<Bytes>>(self, v: T) -> Self

Sets the value of body.

Example
let x = AppEngineHttpTarget::new().set_body(bytes::Bytes::from_static(b"example"));