#[non_exhaustive]pub struct HttpTarget {
pub uri: String,
pub http_method: HttpMethod,
pub headers: HashMap<String, String>,
pub body: Bytes,
pub authorization_header: Option<AuthorizationHeader>,
/* private fields */
}Expand description
Http target. The job will be pushed to the job handler by means of an HTTP request via an http_method such as HTTP POST, HTTP GET, etc. The job is acknowledged by means of an HTTP response code in the range [200 - 299]. A failure to receive a response constitutes a failed execution. For a redirected request, the response returned by the redirected request is considered.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.uri: StringRequired. The full URI path that the request will be sent to. This string
must begin with either “http://” or “https://”. Some examples of
valid values for uri are:
<http://acme.com> and <https://acme.com/sales:8080>. Cloud Scheduler will
encode some characters for safety and compatibility. The maximum allowed
URL length is 2083 characters after encoding.
http_method: HttpMethodWhich HTTP method to use for the request.
headers: HashMap<String, String>HTTP request headers.
This map contains the header field names and values.
The user can specify HTTP request headers to send with the job’s HTTP request. Repeated headers are not supported, but a header value can contain commas.
The following headers represent a subset of the headers that accompany the job’s HTTP request. Some HTTP request headers are ignored or replaced. A partial list of headers that are ignored or replaced is below:
- Host: This will be computed by Cloud Scheduler and derived from uri.
Content-Length: This will be computed by Cloud Scheduler.User-Agent: This will be set to"Google-Cloud-Scheduler".X-Google-*: Google internal use only.X-AppEngine-*: Google internal use only.X-CloudScheduler: This header will be set to true.X-CloudScheduler-JobName: This header will contain the job name.X-CloudScheduler-ScheduleTime: For Cloud Scheduler jobs specified in the unix-cron format, this header will contain the job schedule as an offset of UTC parsed according to RFC3339.
If the job has a body and the following headers are not set by the user, Cloud Scheduler sets default values:
Content-Type: This will be set to"application/octet-stream". You can override this default by explicitly settingContent-Typeto a particular media type when creating the job. For example, you can setContent-Typeto"application/json".
The total size of headers must be less than 80KB.
body: BytesHTTP request body. A request body is allowed only if the HTTP method is POST, PUT, or PATCH. It is an error to set body on a job with an incompatible HttpMethod.
The mode for generating an Authorization header for HTTP requests.
If specified, all Authorization headers in the
HttpTarget.headers field
will be overridden.
Implementations
Sourceimpl HttpTarget
impl HttpTarget
pub fn new() -> Self
Sourcepub fn set_http_method<T: Into<HttpMethod>>(self, v: T) -> Self
pub fn set_http_method<T: Into<HttpMethod>>(self, v: T) -> Self
Sets the value of http_method.
Example
use google_cloud_scheduler_v1::model::HttpMethod;
let x0 = HttpTarget::new().set_http_method(HttpMethod::Post);
let x1 = HttpTarget::new().set_http_method(HttpMethod::Get);
let x2 = HttpTarget::new().set_http_method(HttpMethod::Head);Sourcepub fn set_headers<T, K, V>(self, v: T) -> Self
pub fn set_headers<T, K, V>(self, v: T) -> Self
Sets the value of authorization_header.
Note that all the setters affecting authorization_header are mutually
exclusive.
Example
use google_cloud_scheduler_v1::model::OAuthToken;
let x = HttpTarget::new().set_authorization_header(Some(
google_cloud_scheduler_v1::model::http_target::AuthorizationHeader::OauthToken(OAuthToken::default().into())));Sourcepub fn oauth_token(&self) -> Option<&Box<OAuthToken>>
pub fn oauth_token(&self) -> Option<&Box<OAuthToken>>
The value of authorization_header
if it holds a OauthToken, None if the field is not set or
holds a different branch.
Sourcepub fn set_oauth_token<T: Into<Box<OAuthToken>>>(self, v: T) -> Self
pub fn set_oauth_token<T: Into<Box<OAuthToken>>>(self, v: T) -> Self
Sets the value of authorization_header
to hold a OauthToken.
Note that all the setters affecting authorization_header are
mutually exclusive.
Example
use google_cloud_scheduler_v1::model::OAuthToken;
let x = HttpTarget::new().set_oauth_token(OAuthToken::default()/* use setters */);
assert!(x.oauth_token().is_some());
assert!(x.oidc_token().is_none());Sourcepub fn oidc_token(&self) -> Option<&Box<OidcToken>>
pub fn oidc_token(&self) -> Option<&Box<OidcToken>>
The value of authorization_header
if it holds a OidcToken, None if the field is not set or
holds a different branch.
Sourcepub fn set_oidc_token<T: Into<Box<OidcToken>>>(self, v: T) -> Self
pub fn set_oidc_token<T: Into<Box<OidcToken>>>(self, v: T) -> Self
Sets the value of authorization_header
to hold a OidcToken.
Note that all the setters affecting authorization_header are
mutually exclusive.
Example
use google_cloud_scheduler_v1::model::OidcToken;
let x = HttpTarget::new().set_oidc_token(OidcToken::default()/* use setters */);
assert!(x.oidc_token().is_some());
assert!(x.oauth_token().is_none());Trait Implementations
Sourceimpl Clone for HttpTarget
impl Clone for HttpTarget
Sourcefn clone(&self) -> HttpTarget
fn clone(&self) -> HttpTarget
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more